#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>

#include "src/i2c.h"

#define MCP4726_I2C_ADDR 	0x60
#define MCP4726_CMD_VOLALL	0x40

static void display_help(const char * name)
{
    	fprintf(stderr, "usage: %s voltage\n", name);
}

int main (int argc, char *argv[])
{
    if (argc < 2){
	display_help(argv[0]);
	exit(EXIT_FAILURE);
    }
	
    i2c_t i2c;

    /* Open the i2c-2 bus on WaRP7 */
    if (i2c_open(&i2c, "/dev/i2c-2") < 0) {
        fprintf(stderr, "i2c_open(): %s\n", i2c_errmsg(&i2c));
        exit(1);
    }

    uint8_t msg_addr[1] = { 0x00 };
    uint8_t msg_data[3] = { 0 };
    
    uint16_t level = (atof(argv[1]) * 4095 / 5);
    
    msg_data[0] = MCP4726_CMD_VOLALL;
    msg_data[1] = level / 16;
    msg_data[2] = (level % 16) << 4;
         
    struct i2c_msg msgs[2] =
    {
            { 
            	.addr = MCP4726_I2C_ADDR, 
            	.flags = 0, 
            	.len = 1, 
            	.buf = msg_addr 
            },
            { 	.addr = MCP4726_I2C_ADDR, 
		.flags = 0, 
		.len = 3, 
		.buf = msg_data
            },
    };

    /* Transfer a transaction with two I2C messages */
    if (i2c_transfer(&i2c, msgs, 2) < 0) {
        fprintf(stderr, "i2c_transfer(): %s\n", i2c_errmsg(&i2c));
        exit(1);
    }

    i2c_close(&i2c);
    
    return 0;
}
